from typing import Dict, List, Tuple, Union
from sohstationviewer.view.util.enums import LogType


def get_soh_messages_for_view(
        key: Union[str, Tuple[str, str]],
        soh_messages: Dict[str, Union[List[str], Dict[str, List[str]]]]) ->\
        Dict[str, List[str]]:
    """
    Convert SOH message of the selected key and TEXT log to dict of list of str
        to display

    :param key: key of selected data set: station_id
        or (experiment_number, serial)
    :type key: str/ (str, str)
    :param soh_messages: {'TEXT': log_text, key:{chan_id: sos_messages,},}
    :type soh_messages: Dict
    :return: {'TEXT'/chan_id: [str,]
    :rtype: Dict
    """

    soh_message_view = {}

    if 'TEXT' in soh_messages.keys() and soh_messages['TEXT'] != []:
        soh_message_view['TEXT'] = []
        for msg_list in soh_messages['TEXT']:
            for msg in msg_list.split('\n'):
                soh_message_view['TEXT'].append(msg)

    for chan_id in soh_messages[key]:
        soh_message_view[chan_id] = []

        for msg_lines in soh_messages[key][chan_id]:
            for msg in msg_lines.split('\n'):
                soh_message_view[chan_id].append(msg)
    return soh_message_view


def log_str(log_info: Tuple[str, LogType]) -> str:
    """
    Convert log_info to string that showing log line in saved file
    :param log_info: tuple include text and type of a log line
    :type log_info: Tuple[str, LogType]
    :return: line of log to save in file
    :rtype: str
    """
    log_text, log_type = log_info
    return f"{log_type.name}: {log_text}"
